compute_delta

Function compute_delta 

pub fn compute_delta(desired: &Value, reported: &Value) -> Option<Value>
Compute state.delta: the subset of desired whose value differs from reported (a leaf missing from reported, or nested objects that differ). Returns None when there is no difference.