stamp_metadata

Function stamp_metadata 

pub fn stamp_metadata(meta: &mut Value, patch: &Value, ts: i64)
Stamp per-leaf metadata timestamps for every leaf touched by patch. A null leaf in patch removes the corresponding metadata leaf; objects recurse; arrays become an array of { "timestamp": ts } (one per element); scalars become { "timestamp": ts }.